require 'csv'
require 'json'
require 'fileutils'
require 'thor'
require 'fog'

require_relative 'services'
require_relative 'services/aws'

module Client

  attr_accessor :config

  class << self

    def setup

      home = Dir.home
      @config_file_path = home+"/.mist"

      if File.exists? (@config_file_path)
        @config = JSON.parse(IO.read(@config_file_path), :symbolize_names => true)
      else

        @config = Hash.new

        @config[:profile] = {
            :global_id => (0...50).map { ('a'..'z').to_a[rand(26)] }.join,
            :installation => Time.now.to_s,
            :config_file_version => 1
        }

        @config[:services] = {}

        File.open(@config_file_path,"w") do |f|
          f.write(@config.to_json)
        end

      end
    end

    def get_config
      @config
    end

    def set_config changes
      @config.merge(changes)
      File.open(@config_file_path, "w") do |f|
        f.write(@config.to_json)
      end
    end

  end

end

